@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# TextMIDITools Version 1.0.18
+# TextMIDITools Version 1.0.19
 # textmidiform.py 1.0
 # Copyright © 2022 Thomas E. Janzen
 # License GPLv3+: GNU GPL version 3 or later <https://gnu.org/licenses/gpl.html>
@@ -34,11 +34,11 @@ class FormFrame(tkinter.Frame):
         self.form_title_label.grid(row=0, column=0)
 
         if (self.mean_on):
-            self.mean = Sine(parent=self, sine_title="Mean", period_callback=self.mean_period_callback, phase_callback=self.mean_phase_callback, xml_sine=self.xml_subform['mean'])
+            self.mean = Sine(parent=self, sine_title='Mean', period_callback=self.mean_period_callback, phase_callback=self.mean_phase_callback, xml_sine=self.xml_subform['mean'])
             self.mean.grid(row=self.the_row, column=2, sticky=NSEW, padx=10, pady=10)
             self.the_row =  self.the_row + 1
         if (self.range_on):
-            self.range = Sine(parent=self, sine_title="Range", period_callback=self.range_period_callback, phase_callback=self.range_phase_callback, xml_sine=self.xml_subform['range'])
+            self.range = Sine(parent=self, sine_title='Range', period_callback=self.range_period_callback, phase_callback=self.range_phase_callback, xml_sine=self.xml_subform['range'])
             self.range.grid(row=self.the_row, column=2, sticky=NSEW, padx=10, pady=10)
 
     def install_xml_subform(self, xml_subform):
